# -*- coding: utf-8 -*-

# Future
from __future__ import unicode_literals

# Django
from django import forms
from django.contrib import admin
from django.contrib import messages
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ungettext

# Local
from .conf import settings
from .models import Template
from .utils.template import check_template_syntax


def action_check_template_syntax(modeladmin, request, queryset):
    errors = []
    for template in queryset:
        valid, error = check_template_syntax(template)
        if not valid:
            errors.append('%s#%d: %s' % (template.name, template.pk, error))
    if errors:
        for error in errors:
            modeladmin.message_user(
                request,
                'Template Error: {}'.format(error),
                level=messages.ERROR,
                )
    else:
        count = queryset.count()
        message = ungettext(
            'Template syntax OK.',
            'Template syntax OK for %(count)d templates.', count)
        modeladmin.message_user(request, message % {'count': count})


action_check_template_syntax.short_description = _('Check template syntax')


if settings.CONTEMPLATE_AUTO_POPULATE_CONTENT:
    content_help_text = _(
        'Leaving this empty causes Django to look for a '
        'template with the given name and populate this '
        'field with its content.'
        )
else:
    content_help_text = ''


TemplateContentTextArea = forms.Textarea


class TemplateAdminForm(forms.ModelForm):
    """
    Custom AdminForm to make the content textarea wider.
    """
    content = forms.CharField(
        widget=TemplateContentTextArea(attrs={'rows': '24'}),
        help_text=content_help_text, required=False)

    class Meta:
        model = Template
        fields = ('name', 'content', 'sites', 'created', 'modified')
        fields = '__all__'


class TemplateAdmin(admin.ModelAdmin):
    form = TemplateAdminForm
    list_display = ('name', 'created', 'modified')
    actions = [action_check_template_syntax]
    readonly_fields = ('created', 'modified')


admin.site.register(Template, TemplateAdmin)
